"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.STSHelper = void 0;
const AWS = require("aws-sdk");
const uuid_1 = require("uuid");
const typescript_helper_functions_1 = require("typescript-helper-functions");
/**
 * STS Helper
 */
class STSHelper extends typescript_helper_functions_1.BaseClass {
    /**
     * Initializes new instance of STSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.STS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.STS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.STS(options);
    }
    /**
     * Assume role in your account or another
     * @param roleArn {string} Role ARN to assume
     */
    AssumeRoleAsync(roleArn) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${STSHelper.name}.${this.AssumeRoleAsync.name}`;
            this.LogHelper.LogInputs(action, { roleArn });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(roleArn)) {
                throw new Error(`[${action}]-Must supply roleArn`);
            }
            // create params object
            const params = {
                RoleArn: roleArn,
                RoleSessionName: uuid_1.v4(),
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.assumeRole(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
}
exports.STSHelper = STSHelper;
//# sourceMappingURL=helper.js.map